@@ -28,7 +28,13 @@ Foundation, Inc.,  51 Franklin Street, Fifth Floor, Boston, MA
 02110-1301 USA
 """
 
-from configparser import SafeConfigParser
+import sys
+
+if sys.version_info < (3, 2):
+    from configparser import SafeConfigParser as ConfigParser
+else:
+    from configparser import ConfigParser
+
 import platform
 import os.path
 
@@ -41,8 +47,21 @@ def get_platform_image_viewer():
         return "open"
     elif plat == "Linux":
         # Linux has a whole lot of choices, try to find one
-        choices = ["eog", "gthumb", "gqview", "kuickshow", "xnview", "display",
-                   "gpicview", "gwenview", "qiv", "gimv", "ristretto"]
+        choices = [
+            "eog",
+            "gthumb",
+            "gqview",
+            "kuickshow",
+            "xnview",
+            "display",
+            "gpicview",
+            "gwenview",
+            "qiv",
+            "gimv",
+            "ristretto",
+            "geeqie",
+            "eom",
+        ]
         paths = ["/usr/bin", "/bin"]
         for path in paths:
             for choice in choices:
@@ -50,7 +69,29 @@ def get_platform_image_viewer():
                 if os.path.isfile(full_path):
                     return full_path
         return ""
-    elif plat == "Windows" or plat == "Microsoft":    # Thanks to Dale Hunscher
+    elif plat == "FreeBSD":
+        # FreeBSD also has a whole lot of choices, try to find one
+        choices = [
+            "eog",
+            "gthumb",
+            "geeqie",
+            "display",
+            "gpicview",
+            "gwenview",
+            "qiv",
+            "gimv",
+            "ristretto",
+            "geeqie",
+            "eom",
+        ]
+        paths = ["%%LOCALBASE%%/bin"]
+        for path in paths:
+            for choice in choices:
+                full_path = os.path.join(path, choice)
+                if os.path.isfile(full_path):
+                    return full_path
+        return ""
+    elif plat == "Windows" or plat == "Microsoft":  # Thanks to Dale Hunscher
         # Use the built-in Windows image viewer, if available
         return "start"
     else:
@@ -145,16 +186,6 @@ class Configuration(object):
           vertices automatically if they don't fit within the vertex.
           Default: C{False}.
 
-    Remote repository settings
-    --------------------------
-
-    These settings specify how igraph should access remote graph repositories.
-    Currently only the Nexus repository is supported. All these settings are
-    stored in section C{remote}.
-
-        - B{nexus.url}: the root URL of the Nexus repository. Default:
-          C{http://nexus.igraph.org}.
-
     Shell settings
     --------------
 
@@ -224,57 +255,21 @@ class Configuration(object):
             obj.set(section, key, str(float(value)))
 
     _types = {
-        "boolean": {
-            "getter": SafeConfigParser.getboolean,
-            "setter": Types.setboolean
-        },
-        "int": {
-            "getter": SafeConfigParser.getint,
-            "setter": Types.setint
-        },
-        "float": {
-            "getter": SafeConfigParser.getfloat,
-            "setter": Types.setfloat
-        }
+        "boolean": {"getter": ConfigParser.getboolean, "setter": Types.setboolean},
+        "int": {"getter": ConfigParser.getint, "setter": Types.setint},
+        "float": {"getter": ConfigParser.getfloat, "setter": Types.setfloat},
     }
 
     _sections = ("general", "apps", "plotting", "remote", "shell")
     _definitions = {
-        "general.shells": {
-            "default": "IPythonShell,ClassicPythonShell"
-        },
-        "general.verbose": {
-            "default": True,
-            "type": "boolean"
-        },
-
-        "apps.image_viewer": {
-            "default": get_platform_image_viewer()
-        },
-
-        "plotting.layout": {
-            "default": "auto"
-        },
-        "plotting.mark_groups": {
-            "default": False,
-            "type": "boolean"
-        },
-        "plotting.palette": {
-            "default": "gray"
-        },
-        "plotting.wrap_labels": {
-            "default": False,
-            "type": "boolean"
-        },
-
-        "remote.nexus.url": {
-            "default": "http://nexus.igraph.org"
-        },
-
-        "shell.ipython.inlining.Plot": {
-            "default": True,
-            "type": "boolean"
-        }
+        "general.shells": {"default": "IPythonShell,ClassicPythonShell"},
+        "general.verbose": {"default": True, "type": "boolean"},
+        "apps.image_viewer": {"default": get_platform_image_viewer()},
+        "plotting.layout": {"default": "auto"},
+        "plotting.mark_groups": {"default": False, "type": "boolean"},
+        "plotting.palette": {"default": "gray"},
+        "plotting.wrap_labels": {"default": False, "type": "boolean"},
+        "shell.ipython.inlining.Plot": {"default": True, "type": "boolean"},
     }
 
     # The singleton instance we are using throughout other modules
@@ -285,7 +280,7 @@ class Configuration(object):
 
         @param filename: file or file pointer to be read. Can be omitted.
         """
-        self._config = SafeConfigParser()
+        self._config = ConfigParser()
         self._filename = None
 
         # Create default sections
